import { Catalog, TranslationPrepareResult } from '@cloudflare/intl-types';
/**
 * Prepares a catalog for use with our intl libraries and exports
 * a keys object, which can be used to get the final key of a string:
 *
 * @example
 * import { prepareTranslations } from '@cloudflare/intl-core'
 * import { Trans } from '@cloudflare/intl-react'
 * const { keys, translations } = prepareTranslations('my-product', {
 *   someFeature: {
 *     title: 'Some feature title',
 *     description: 'Some feature description',
 *   },
 *   help: 'The help text'
 * })
 *
 * console.log(keys.someFeature.title) // "my-product.someFeature.title"
 *
 * <Trans id={keys.someFeature.description} />
 *
 * @param namespace Namespace of the catalog (prefixes with "${namespace}.")
 * @param trans The unprefixed keys/vals of the english catalog
 */
export declare function prepareTranslations<T extends Catalog>(namespace: string, trans: T): TranslationPrepareResult<T>;
